@@ -30,7 +30,7 @@ class BulkReadOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/bulk/v2.1/read/'
+		api_path = api_path + '/crm/bulk/v2/read/'
 		api_path = api_path + str(job_id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
@@ -60,7 +60,7 @@ class BulkReadOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/bulk/v2.1/read/'
+		api_path = api_path + '/crm/bulk/v2/read/'
 		api_path = api_path + str(job_id)
 		api_path = api_path + '/result'
 		handler_instance.set_api_path(api_path)
@@ -96,7 +96,7 @@ class BulkReadOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/bulk/v2.1/read'
+		api_path = api_path + '/crm/bulk/v2/read'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
