@@ -21,15 +21,12 @@ class Module(object):
 		self.__modified_time = None
 		self.__plural_label = None
 		self.__presence_sub_menu = None
-		self.__isblueprintsupported = None
 		self.__triggers_supported = None
 		self.__id = None
 		self.__related_list_properties = None
 		self.__properties = None
-		self.__on_demand_properties = None
 		self.__per_page = None
 		self.__visibility = None
-		self.__visible = None
 		self.__convertable = None
 		self.__editable = None
 		self.__emailtemplate_support = None
@@ -325,30 +322,6 @@ class Module(object):
 		self.__presence_sub_menu = presence_sub_menu
 		self.__key_modified['presence_sub_menu'] = 1
 
-	def get_isblueprintsupported(self):
-		"""
-		The method to get the isblueprintsupported
-
-		Returns:
-			bool: A bool representing the isblueprintsupported
-		"""
-
-		return self.__isblueprintsupported
-
-	def set_isblueprintsupported(self, isblueprintsupported):
-		"""
-		The method to set the value to isblueprintsupported
-
-		Parameters:
-			isblueprintsupported (bool) : A bool representing the isblueprintsupported
-		"""
-
-		if isblueprintsupported is not None and not isinstance(isblueprintsupported, bool):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: isblueprintsupported EXPECTED TYPE: bool', None, None)
-		
-		self.__isblueprintsupported = isblueprintsupported
-		self.__key_modified['isBlueprintSupported'] = 1
-
 	def get_triggers_supported(self):
 		"""
 		The method to get the triggers_supported
@@ -450,30 +423,6 @@ class Module(object):
 		self.__properties = properties
 		self.__key_modified['$properties'] = 1
 
-	def get_on_demand_properties(self):
-		"""
-		The method to get the on_demand_properties
-
-		Returns:
-			list: An instance of list
-		"""
-
-		return self.__on_demand_properties
-
-	def set_on_demand_properties(self, on_demand_properties):
-		"""
-		The method to set the value to on_demand_properties
-
-		Parameters:
-			on_demand_properties (list) : An instance of list
-		"""
-
-		if on_demand_properties is not None and not isinstance(on_demand_properties, list):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: on_demand_properties EXPECTED TYPE: list', None, None)
-		
-		self.__on_demand_properties = on_demand_properties
-		self.__key_modified['$on_demand_properties'] = 1
-
 	def get_per_page(self):
 		"""
 		The method to get the per_page
@@ -522,30 +471,6 @@ class Module(object):
 		self.__visibility = visibility
 		self.__key_modified['visibility'] = 1
 
-	def get_visible(self):
-		"""
-		The method to get the visible
-
-		Returns:
-			bool: A bool representing the visible
-		"""
-
-		return self.__visible
-
-	def set_visible(self, visible):
-		"""
-		The method to set the value to visible
-
-		Parameters:
-			visible (bool) : A bool representing the visible
-		"""
-
-		if visible is not None and not isinstance(visible, bool):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: visible EXPECTED TYPE: bool', None, None)
-		
-		self.__visible = visible
-		self.__key_modified['visible'] = 1
-
 	def get_convertable(self):
 		"""
 		The method to get the convertable
