@@ -39,7 +39,7 @@ class NotificationOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/actions/watch'
+		api_path = api_path + '/crm/v2/actions/watch'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
@@ -71,7 +71,7 @@ class NotificationOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/actions/watch'
+		api_path = api_path + '/crm/v2/actions/watch'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -106,7 +106,7 @@ class NotificationOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/actions/watch'
+		api_path = api_path + '/crm/v2/actions/watch'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
@@ -143,7 +143,7 @@ class NotificationOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/actions/watch'
+		api_path = api_path + '/crm/v2/actions/watch'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PATCH)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
@@ -175,7 +175,7 @@ class NotificationOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/actions/watch'
+		api_path = api_path + '/crm/v2/actions/watch'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
@@ -210,7 +210,7 @@ class NotificationOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2.1/actions/watch'
+		api_path = api_path + '/crm/v2/actions/watch'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PATCH)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
