@@ -49,7 +49,7 @@ class LicenseDetails(object):
 		The method to get the users_license_purchased
 
 		Returns:
-			int: A int value
+			int: An int representing the users_license_purchased
 		"""
 
 		return self.__users_license_purchased
@@ -73,7 +73,7 @@ class LicenseDetails(object):
 		The method to get the trial_type
 
 		Returns:
-			string: A string value
+			string: A string representing the trial_type
 		"""
 
 		return self.__trial_type
@@ -97,7 +97,7 @@ class LicenseDetails(object):
 		The method to get the trial_expiry
 
 		Returns:
-			string: A string value
+			string: A string representing the trial_expiry
 		"""
 
 		return self.__trial_expiry
@@ -121,7 +121,7 @@ class LicenseDetails(object):
 		The method to get the paid
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the paid
 		"""
 
 		return self.__paid
@@ -145,7 +145,7 @@ class LicenseDetails(object):
 		The method to get the paid_type
 
 		Returns:
-			string: A string value
+			string: A string representing the paid_type
 		"""
 
 		return self.__paid_type
@@ -172,7 +172,7 @@ class LicenseDetails(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
