@@ -19,7 +19,7 @@ class Participants(Record):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.get_key_value('name')
@@ -42,7 +42,7 @@ class Participants(Record):
 		The method to get the email
 
 		Returns:
-			string: A string value
+			string: A string representing the email
 		"""
 
 		return self.get_key_value('Email')
@@ -65,7 +65,7 @@ class Participants(Record):
 		The method to get the invited
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the invited
 		"""
 
 		return self.get_key_value('invited')
@@ -88,7 +88,7 @@ class Participants(Record):
 		The method to get the type
 
 		Returns:
-			string: A string value
+			string: A string representing the type
 		"""
 
 		return self.get_key_value('type')
@@ -111,7 +111,7 @@ class Participants(Record):
 		The method to get the participant
 
 		Returns:
-			string: A string value
+			string: A string representing the participant
 		"""
 
 		return self.get_key_value('participant')
@@ -134,7 +134,7 @@ class Participants(Record):
 		The method to get the status
 
 		Returns:
-			string: A string value
+			string: A string representing the status
 		"""
 
 		return self.get_key_value('status')
