@@ -19,8 +19,6 @@ class Constants(object):
 
     REQUEST_METHOD_DELETE = "DELETE"
 
-    GIVEN_VALUE = "given-value"
-
     REQUEST_METHOD_PATCH = 'PATCH'
 
     OAUTH_HEADER_PREFIX = "Zoho-oauthtoken "
@@ -29,99 +27,8 @@ class Constants(object):
 
     API_NAME = "api_name"
 
-    PHOTO = "photo"
-
-    API_VERSION = "v2.1"
-
-    CRM = "crm"
-
-    INPUT_ERROR = "INPUT_ERROR"
-
-    KEY_VS_INVENTORY_MODULE = {
-        "Quoted_Items": "quotes",
-
-        "Invoiced_Items": "invoices",
-
-        "Purchase_Items": "purchase_orders",
-
-        "Ordered_Items": "sales_orders"
-
-    }
-
-    DEFAULT_MODULENAME_VS_APINAME = {
-
-        "leads": "Leads",
-
-        "contacts": "Contacts",
-
-        "accounts": "Accounts",
-
-        "deals": "Deals",
-
-        "tasks": "Tasks",
-
-        "events": "Events",
-
-        "activities": "Activities",
-
-        "calls": "Calls",
-
-        "products": "Products",
-
-        "quotes": "Quotes",
-
-        "sales_orders": "Sales_Orders",
-
-        "purchase_orders": "Purchase_Orders",
-
-        "invoices": "Invoices",
-
-        "campaigns": "Campaigns",
-
-        "vendors": "Vendors",
-
-        "price_books": "Price_Books",
-
-        "cases": "Cases",
-
-        "solutions": "Solutions",
-
-        "visits": "Visits",
-
-        "approvals": "Approvals",
-
-        "notes": "Notes",
-
-        "attachments": "Attachments",
-
-        "actions_performed": "Actions_Performed",
-
-    }
-
-    PROXY_SETTINGS = "Proxy settings - "
-
-    PROXY_HOST = "Host: "
-
-    PROXY_PORT = "Port: "
-
-    PROXY_USER = "User: "
-
-    PROXY_DOMAIN = "Domain: "
-
-    GET_TOKEN_BY_ID_DB_ERROR = "Exception in getTokenById - DBStore : Given ID is invalid"
-
-    GET_TOKEN_BY_ID_FILE_ERROR = "Exception in getTokenById - FileStore : Given ID is invalid"
-
-    MYSQL_TABLE_NAME = "oauthtoken"
-
-    SWITCH_USER_ERROR = "SWITCH USER ERROR"
-
-    LOGGER_INITIALIZATION_ERROR = "Exception in Logger Initialization : "
-
     INVALID_ID_MSG = "The given id seems to be invalid."
 
-    RESOURCE_PATH_INVALID_ERROR_MESSAGE = "Resource Path MUST be a valid directory."
-
     API_MAX_RECORDS_MSG = "Cannot process more than 100 records at a time."
 
     INVALID_DATA = "INVALID_DATA"
@@ -148,13 +55,9 @@ class Constants(object):
 
     CLIENT_SECRET = "client_secret"
 
-    REDIRECT_URI = "redirect_uri"
+    REDIRECT_URL = "redirect_uri"
 
-    REDIRECT_URL = "redirect_url"
-
-    OBJECT = "Object"
-
-    DATA_TYPE = {
+    TYPE_VS_DATATYPE = {
         "String": str,
         "List": list,
         "Integer": int,
@@ -170,13 +73,11 @@ class Constants(object):
 
     OBJECT_KEY = "object"
 
-    PHOTO_SUPPORTED_MODULES = ["Leads", "Contacts", "Accounts", "Products", "Vendors", "Deals", "Cases", "Solutions"]
-
     GIVEN_LENGTH = "given-length"
 
     ZOHO_SDK = "X-ZOHO-SDK"
 
-    SDK_VERSION = "1.0.0"
+    SDK_VERSION = "3.1.0"
 
     CONTENT_DISPOSITION = "Content-Disposition"
 
@@ -320,10 +221,6 @@ class Constants(object):
 
     REMINDER_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Reminder"
 
-    TERRITORY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Territory"
-
-    IMAGEUPLOAD_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.ImageUpload"
-
     ATTACHMENTS_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.attachments.Attachment"
 
     RECURRING_ACTIVITY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.RecurringActivity"
@@ -356,14 +253,6 @@ class Constants(object):
 
     EXPECTED_TYPE = "expected-type"
 
-    USER_AGENT = "Mozilla/5.0"
-
-    USER_AGENT_KEY = "user-agent"
-
-    AT = '@'
-
-    EXPECTED_TOKEN_TYPES = 'REFRESH, GRANT'
-
     INITIALIZATION_ERROR = "INITIALIZATION ERROR"
 
     ENVIRONMENT = "environment"
@@ -380,7 +269,7 @@ class Constants(object):
 
     EMAIL = "email"
 
-    USER_SIGNATURE_ERROR = "USERSIGNATURE ERROR"
+    USER_SIGNATURE_ERROR = "USERSIGNATURE ERROR";
 
     USER_INITIALIZATION_ERROR = "Error during User Initialization"
 
@@ -488,7 +377,7 @@ class Constants(object):
 
     RESOURCE_PATH_ERROR_MESSAGE = "Resource Path MUST NOT be None/empty."
 
-    SET_CONTENT_TYPE_HEADER = ["/crm/bulk/v2.1/read", "/crm/bulk/v2.1/write"]
+    SET_TO_CONTENT_TYPE = ["/crm/bulk/v2/read", "/crm/bulk/v2/write"]
 
     CONTENT_TYPE_HEADER = "Content-Type"
 
@@ -498,30 +387,6 @@ class Constants(object):
 
     FILE_ID = "file_id"
 
-    PHOTO_UPLOAD_ERROR_MESSAGE = "The given module is not supported in API."
-
-    INVALID_MODULE = "INVALID_MODULE"
-
-    MULTI_SELECT_LOOKUP = "multiselectlookup"
-
-    MULTI_USER_LOOKUP = "multiuserlookup"
-
-    TERRITORIES = "territories"
-
-    GENERATED_TYPE = "generated_type"
-
-    GENERATED_TYPE_CUSTOM = "custom"
-
-    UPLOAD_PHOTO_UNSUPPORTED_MESSAGE = "Photo Upload Operation is not supported by the module: "
-
-    SDK_MODULE_METADATA = "SDK-MODULE-METADATA"
-
-    INVALID_MODULE_API_NAME_ERROR = "INVALID MODULE API NAME ERROR"
-
-    PROVIDE_VALID_MODULE_API_NAME = "PROVIDE VALID MODULE API NAME: "
-
-    UPLOAD_PHOTO_UNSUPPORTED_ERROR = "UPLOAD PHOTO UNSUPPORTED MODULE"
-
     DELETE_FIELD_FILE_ERROR = "Exception in deleting Current User Fields file : "
 
     DELETE_FIELD_FILES_ERROR = "Exception in deleting all Fields files : "
@@ -620,6 +485,8 @@ class Constants(object):
 
     PARAM_NAME_NONE_ERROR_MESSAGE = "Param Name MUST NOT be None"
 
+    SWITCH_USER_ERROR = "SWITCH USER ERROR"
+
     USER_PROXY_ERROR = "USERPROXY ERROR"
 
     HOST_ERROR_MESSAGE = "Host MUST NOT be None"
@@ -638,6 +505,14 @@ class Constants(object):
 
     ATTACHMENTS = "$attachments"
 
+    PROXY_SETTINGS = "Proxy settings - "
+
+    PROXY_HOST = "Host: "
+
+    PROXY_PORT = "Port: "
+
+    PROXY_USER = "User: "
+
     JSON_FILE_EXTENSION = ".json"
 
     FILE_ERROR = "file_error"
@@ -651,11 +526,3 @@ class Constants(object):
     USER_MAIL_NULL_ERROR_MESSAGE = "User Mail MUST NOT be None. Set value to user_mail."
 
     JSON_DETAILS_ERROR = "ERROR IN READING JSONDETAILS FILE"
-
-    INVALID_TOKEN_ERROR = "INVALID TOKEN ERROR"
-
-    NO_ACCESS_TOKEN_ERROR = "ACCESS TOKEN IS NOT PRESENT IN RESPONSE"
-
-    CLIENT_ID_NULL_ERROR_MESSAGE = "ClientID MUST NOT be null"
-
-    CLIENT_SECRET_NULL_ERROR_MESSAGE = "ClientSecret MUST NOT be null"
